Re-exports
pub use bsdf::*;pub use camera::*;pub use hit::*;pub use material::*;pub use plane::*;pub use ray::*;pub use rectangle::*;pub use scene::*;pub use sphere::*;pub use triangle::*;Modules
Axis Aligned Bounding Boxes.
Axis enum for indexing three-dimensional structures.
This module defines the BoundingHierarchy trait.
This module exports methods to flatten the BVH and traverse it iteratively.
This module defines a Ray structure and intersection algorithms for axis aligned bounding boxes and triangles.
Enums
Constants
A minimal floating value used as a lower bound. TODO: replace by/add ULPS/relative float comparison methods.